@@ -20,26 +20,34 @@ lapply(
       model = model,
       data = data
     )
-    set.seed(seed)
-    results_chol <- MC(
-      fit,
-      R = R,
-      alpha = c(0.001, 0.01, 0.05),
-      decomposition = "chol"
+    run <- TRUE
+    tryCatch(
+      {
+        results_chol <- MC(
+          fit,
+          R = R,
+          alpha = c(0.001, 0.01, 0.05),
+          decomposition = "chol",
+          seed = seed
+        )
+      },
+      error = function() {
+        run <- FALSE # nolint
+      }
     )
-    set.seed(seed)
     results_eigen <- MC(
       fit,
       R = R,
       alpha = c(0.001, 0.01, 0.05),
-      decomposition = "eigen"
+      decomposition = "eigen",
+      seed = seed
     )
-    set.seed(seed)
     results_svd <- MC(
       fit,
       R = R,
       alpha = c(0.001, 0.01, 0.05),
-      decomposition = "svd"
+      decomposition = "svd",
+      seed = seed
     )
     set.seed(seed)
     answers <- MASS::mvrnorm(
